@@ -86,7 +86,7 @@
 #define KTEXTEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTEDITOR_NO_DEPRECATED
-#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
+#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KTEXTEDITOR_NO_DEPRECATED_WARNINGS
 #  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x55c00
+#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KTEXTEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTEDITOR_NO_DEPRECATED
-#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
+#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KTEXTEDITOR_NO_DEPRECATED_WARNINGS
 #  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x55c00
+#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
